
# Type: caused by


holds between two entities where the occurrence, existence, or activity of one is caused by the occurrence or  generation of the other

URI: [biolink:caused_by](https://w3id.org/biolink/vocab/caused_by)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by

 * [NamedThing](NamedThing.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | WD:P828 |
| **In Subsets:** | | translator_minimal |

